/*
 *  main.c - Main function (unused under BeOS)
 *
 *  Basilisk (C) 1996 Christian Bauer
 */

#include "sysconfig.h"
#include "sysdeps.h"

#include "config.h"
#include "options.h"
#include "memory.h"
#include "newcpu.h"
#include "debug.h"
#include "xwin.h"
#include "gui.h"
#include "zfile.h"

int version = 100*UAEMAJOR + 10*UAEMINOR + UAEURSAMINOR;
int framerate = 20;
int use_debugger = 0;
int illegal_mem = 0;
int produce_sound = 0;
KbdLang keyboard_lang = KBD_LANG_US;
int boot_edisk = 0;
int no_gui = 0;
char df0[256] = "fd0.image", df1[256] = "fd1.image",
	 df2[256] = "fd2.image", df3[256] = "fd3.image";
char romfile[256] = "ClassicROM";
char pramfile[256] = "PRAM";

#ifndef __BEOS__
static void usage(void)
{
	printf("Basilisk\n");
	printf("Summary of command-line options:\n");
	printf("  -h                 : Print help\n");
	printf("  -f n               : Set the frame rate to n milliseconds\n");
	printf("  -D                 : Start up the built-in debugger\n");
	printf("  -E                 : Boot from ROM .EDisk\n");
	printf("  -[0123] filename   : Use file instead of fd[0123].image as filedisks\n");
	printf("  -r filename        : Use file as ROM image instead of 'ClassicROM'\n");
    printf("  -p filename        : Use filename to save PRAM contents\n");
}

static void parse_cmdline(int argc, char **argv)
{
	int c;
    extern char *optarg;

	while(((c = getopt(argc, argv, "DEf:h0:1:2:3:r:p:")) != EOF)) switch(c) {
     case 'h': usage();	exit(0);

     case '0': strncpy(df0, optarg, 255); df0[255] = 0;	break;
     case '1': strncpy(df1, optarg, 255); df1[255] = 0; break;
     case '2': strncpy(df2, optarg, 255); df2[255] = 0; break;
     case '3': strncpy(df3, optarg, 255); df3[255] = 0; break;
     case 'r': strncpy(romfile, optarg, 255); romfile[255] = 0; break;
     case 'p': strncpy(pramfile, optarg, 255); pramfile[255] = 0; break;		    
	
     case 'f': framerate = atoi(optarg); break;
     case 'D': use_debugger = 1; break;
     case 'E': boot_edisk = 1; break;
	}
}

int main(int argc, char **argv)
{
	parse_cmd_line(argc, argv);
	if (gui_init() < 0) {
		fprintf(stderr, "Failed to initialize GUI.\n");
	}

	memory_init();
	load_pram();
	sony_init();
	filedisk_init();
	init_m68k();

	if (graphics_init()) {
		m68k_reset();
		setup_brkhandler();
		if (use_debugger && debuggable())
			activate_debugger();
		m68k_go(1);
		graphics_leave();
	}
	dump_counts();
	filedisk_exit();
	sony_exit();
	save_pram();
	zfile_exit();
	if (!no_gui)
		gui_exit();
	return 0;
}
#endif
